@@ -32,7 +32,7 @@
  *  Robert Bragg   <robert@linux.intel.com>
  */
 
-#include "cogl-config.h"
+#include "config.h"
 
 #include <string.h>
 
@@ -66,20 +66,6 @@ _cogl_texture_2d_nop_allocate (CoglTexture *tex,
   return TRUE;
 }
 
-void
-_cogl_texture_2d_nop_flush_legacy_texobj_filters (CoglTexture *tex,
-                                                  GLenum min_filter,
-                                                  GLenum mag_filter)
-{
-}
-
-void
-_cogl_texture_2d_nop_flush_legacy_texobj_wrap_modes (CoglTexture *tex,
-                                                     GLenum wrap_mode_s,
-                                                     GLenum wrap_mode_t)
-{
-}
-
 void
 _cogl_texture_2d_nop_copy_from_framebuffer (CoglTexture2D *tex_2d,
                                             int src_x,
@@ -118,11 +104,3 @@ _cogl_texture_2d_nop_copy_from_bitmap (CoglTexture2D *tex_2d,
 {
   return TRUE;
 }
-
-void
-_cogl_texture_2d_nop_get_data (CoglTexture2D *tex_2d,
-                               CoglPixelFormat format,
-                               size_t rowstride,
-                               uint8_t *data)
-{
-}
