@@ -14,14 +14,11 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 
-#ifndef META_SCREEN_CAST_STREAM_H
-#define META_SCREEN_CAST_STREAM_H
+#pragma once
 
 #include <glib-object.h>
 
@@ -43,11 +40,11 @@ struct _MetaScreenCastStreamClass
                                             GError              **error);
   void (* set_parameters) (MetaScreenCastStream *stream,
                            GVariantBuilder      *parameters_builder);
-  void (* transform_position) (MetaScreenCastStream *stream,
-                               double                stream_x,
-                               double                stream_y,
-                               double               *x,
-                               double               *y);
+  gboolean (* transform_position) (MetaScreenCastStream *stream,
+                                   double                stream_x,
+                                   double                stream_y,
+                                   double               *x,
+                                   double               *y);
 };
 
 MetaScreenCastSession * meta_screen_cast_stream_get_session (MetaScreenCastStream *stream);
@@ -61,14 +58,18 @@ char * meta_screen_cast_stream_get_object_path (MetaScreenCastStream *stream);
 
 MetaScreenCastStreamSrc * meta_screen_cast_stream_get_src (MetaScreenCastStream *stream);
 
-void meta_screen_cast_stream_transform_position (MetaScreenCastStream *stream,
-                                                 double                stream_x,
-                                                 double                stream_y,
-                                                 double               *x,
-                                                 double               *y);
+gboolean meta_screen_cast_stream_transform_position (MetaScreenCastStream *stream,
+                                                     double                stream_x,
+                                                     double                stream_y,
+                                                     double               *x,
+                                                     double               *y);
 
 MetaScreenCastCursorMode meta_screen_cast_stream_get_cursor_mode (MetaScreenCastStream *stream);
 
 MetaScreenCastFlag meta_screen_cast_stream_get_flags (MetaScreenCastStream *stream);
 
-#endif /* META_SCREEN_CAST_STREAM_H */
+const char * meta_screen_cast_stream_get_mapping_id (MetaScreenCastStream *stream);
+
+gboolean meta_screen_cast_stream_is_configured (MetaScreenCastStream *stream);
+
+void meta_screen_cast_stream_notify_is_configured (MetaScreenCastStream *stream);
